Division

Enum Division 

pub enum Division {
    Metrical(u16),
    Timecode {
        fps: Fps,
        res: u8,
    },
}
The way time is divided in the midi track

Variants



Metrical(u16)

This means the time is indicated by the number of sub-divisons of a quarter-note (a.k.a. crotchet). For example, 4 would mean the maximum resolution is semi-quavers.

A common choice is 96 = 2^5 * 3 allowing dotted notes down to hemidemisemiquavers



Timecode

The time is absolute, and expresses as a combination of frames per second, and the sub-frame resolution

Fields

fps: Fps

The number of frames per second

res: u8

The sub-frame resolution

Typical values are 4 (corresponding to MIDI Time Code), 8, 10, 80 (corresponding to SMPTE bit resolution), or 100.